@@ -110,3 +110,10 @@ USE_QUEUE = False
 # Instructs Sentry to utilize it's internal search indexer on all incoming
 # events..
 USE_SEARCH = True
+
+
+# Default sort option for the group stream
+DEFAULT_SORT_OPTION = 'date'
+
+# Default sort option for the search results
+SEARCH_DEFAULT_SORT_OPTION = 'date'
